<template>
  <div class="sales-details">
    <div v-if="isDetail" class="detail-top">
      <DetailListCommonBtn />
    </div>

    <div v-else class="filter">
      <div class="filter-card">
        <CommonSearch
          :show-add="false"
          :show-download="false"
          :amount-view="false"
          :show-action-btn="false"
          placeholder="请输入订单编号"
          @searchClick="onFilterSearch"
        >
          <template slot="leftButton">
            <el-button size="small" type="primary" @click="addBtnClick">新建</el-button>
            <!-- <el-button size="small"  @click="delClick">删除</el-button> -->
          </template>
        </CommonSearch>
      </div>
    </div>

    <div class="body">
      <!-- <div class="body-card"> -->
      <div class="content-top">
        <div class="list-view">
          <TableCommonView
            ref="tableListRef"
            :show-summary="showSummary"
            :table-list="tableList"
            @selClientClick="selClientClick"
            @selCommonClick="selCommonClick"
            @getSelectArray="getSelectArray"
            @selTableCol="selTableCol"
            @tableRowClick="tableRowClick"
            :selectClassRow="selectRow"
          >
            <template slot="tableButton">
              <el-table-column label="操作" width="180">
                <template slot-scope="scope">
                  <el-button @click="handleClick(scope.row, '查看')" type="text" size="small">查看</el-button>
                  <template v-if="scope.row.status === 1">
                    <el-button @click="handleClick(scope.row, '编辑')" type="text" size="small">编辑</el-button>
                    <el-button @click="submitClick(scope.row)" type="text" size="small">确认提交</el-button>
                    <!-- <el-button @click="delClick(scope.row.id)" type="text" size="small">删除</el-button> -->
                    <el-button @click="closeClick(scope.row.id)" type="text" size="small">关闭</el-button>
                  </template>
                </template>
              </el-table-column>
            </template>
          </TableCommonView>
        </div>
        <div class="btn-pager">
          <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
        </div>
      </div>
      <div class="content-bottom">
        <div class="bottom-tabs" :class="!isDetail ? 'bgcGrey' : 'bgcWhite'">
          <div
            class="tab-pane"
            @click="getTab(0)"
            :style="{
              background: isClickProduct ? '#2a78fb' : '#F1F3F8',
              color: isClickProduct ? '#fff' : '#666'
            }"
          >
            产品信息
          </div>
          <div
            class="tab-pane"
            @click="getTab(1)"
            :style="{
              background: isClickInventory ? '#2a78fb' : '#F1F3F8',
              color: isClickInventory ? '#fff' : '#666'
            }"
          >
            库存信息
          </div>
          <div
            class="tab-pane"
            @click="getTab(2)"
            :style="{
              background: isClickMake ? '#2a78fb' : '#F1F3F8',
              color: isClickMake ? '#fff' : '#666'
            }"
          >
            制造信息
          </div>
        </div>
        <div class="list-view">
          <TableCommonView :loading="loading" :table-list="productTableList" @selTableCol="selBottomTableCol">
            <!-- <template slot="tableButton">
              <el-table-column label="操作" width="160" fixed="right">
                <template slot-scope="scope">
                  <el-button @click="viewClick(scope.row)" type="text" size="small">查看</el-button>
                </template>
              </el-table-column>
            </template> -->
          </TableCommonView>
        </div>
      </div>
    </div>
    <!-- 新建/编辑 -->
    <AddSalesDetailsDialog
      v-if="editConfig.visible"
      :edit-common-config="editConfig"
      @addCollectionPlanClick="addCollectionPlanClick"
    />
    <!-- 销售明细详情 -->
    <DetailSpecification v-if="specificationDetail.visible" :specification-detail="specificationDetail" />
    <!-- 客户详情 -->
    <DetailClientManage v-if="clientDeail.visible" :client-manage-detail="clientDeail" />
    <!-- 新建 收款计划 -->
    <AddCollectionPlan v-if="addCollectionConfig.visible" :edit-common-config="addCollectionConfig" />
  </div>
</template>

<script>
import AddSalesDetailsDialog from "@/views/sales/salesDetails/AddSalesDetailsDialog"
import { getSalesDetailsList, getDelSalesDetails } from "@/api/sales/salesDetails"
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import DetailSpecification from "@/views/sales/salesDetails/DetailSpecification"
import AddCollectionPlan from "@/views/other/payment/collectionPlan/AddCollectionPlan"

export default {
  name: "SalesDetails",
  props: {
    isDetail: {
      type: Boolean,
      default: false
    },
    addConfig: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  mixins: [pageMixin],
  components: {
    AddSalesDetailsDialog,
    DetailSpecification,
    DetailClientManage: () => import("@/views/client/client/DetailClientManage"),
    AddCollectionPlan
  },
  computed: {
    searchCommonHeight() {
      return this.$refs.searchCommonView.offsetHeight
    }
  },
  data() {
    // 产品信息
    const productColumn = [
      { label: "产品编号", prop: "number", default: true },
      { label: "产品名称", prop: "client_name" },
      { label: "数量", prop: "signTime" },
      { label: "单位", prop: "member_name" },
      { label: "发货单", prop: "outboundStatus" },
      { label: "承运商", prop: "receiveTotalAmount", price: true },
      { label: "运单号", prop: "total", price: true },
      { label: "销售单价", prop: "taxUnitPrice", isProductPrice: true },
      { label: "价税合计", prop: "priceTax", isProductTotal: true }
    ]
    // 库存信息
    const inventoryColumn = [
      { label: "产品编号", prop: "number", default: true },
      { label: "产品名称", prop: "client_name" },
      { label: "订单数量", prop: "signTime" },
      { label: "仓库", prop: "member_name" },
      { label: "在库数量", prop: "outboundStatus" },
      { label: "可用库存", prop: "receiveTotalAmount", price: true },
      { label: "单位", prop: "total", price: true }
    ]
    // 制造信息
    const makeColumn = [
      { label: "生产订单", prop: "number", default: true },
      { label: "产品名称", prop: "client_name" },
      { label: "订单状态", prop: "signTime" },
      { label: "工单编号", prop: "member_name" },
      { label: "工单状态", prop: "outboundStatus" },
      { label: "计划开始时间", prop: "receiveTotalAmount", price: true },
      { label: "计划结束时间", prop: "total", price: true }
    ]
    return {
      tableList: {},
      searchOptions: [],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      showSummary: {
        show: false,
        sumProp: [
          "receiveTotalAmount",
          "total",
          "amountReceivable",
          "invoicedAmount",
          "uninvoicedAmount",
          "number",
          "unOutoundNo",
          "taxUnitPrice",
          "priceTax"
        ],
        mergeNumber: 6
      },
      specificationDetail: {
        visible: false,
        infomation: {}
      },
      clientDeail: {
        visible: false,
        infomation: {}
      },
      selValueList: [],
      search_map: {},
      searchSel: {
        value: "number",
        label: "订单编号"
      },
      keyword: "",
      keywordType: "",
      addCollectionConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      tableColumn: [
        { label: "订单编号", prop: "number", isCommonClick: true, default: true },
        { label: "销售负责人", prop: "member_name" },
        { label: "签约日期", prop: "signTime" },
        { label: "交付日期", prop: "deliveryDate" },
        { label: "订单来源", prop: "source" },
        { label: "合计", prop: "total", price: true },
        { label: "状态", prop: "status", isCallMethod: true, getCallMethod: this.getStatus }
      ],
      showCol: ["订单编号", "销售负责人", "签约日期", "交付日期", "订单来源", "合计", "状态"],
      tableBottomColumn: [],
      showBottomCol: [],
      isClickProduct: true, // 产品信息
      isClickInventory: false, // 库存信息
      isClickMake: false, // 制造信息
      TabsIndex: "0",
      productTableList: {},
      productColumn: productColumn,
      showProductCol: ["产品编号", "产品名称", "数量", "单位", "发货单", "承运商", "运单号", "销售单价", "价税合计"],
      inventoryColumn: inventoryColumn,
      showInventoryCol: ["产品编号", "产品名称", "订单数量", "仓库", "在库数量", "可用库存", "单位"],
      makeColumn: makeColumn,
      showMakeCol: ["生产订单", "产品名称", "订单状态", "工单编号", "工单状态", "计划开始时间", "计划结束时间"],
      selectRow: {}
    }
  },
  created() {
    this.setTable()
    if (!this.isDetail) {
      this.keyword = ""
      this.keywordType = ""
    } else {
      this.keyword = this.addConfig.keyword
      this.keywordType = this.addConfig.keywordType
    }
    this.getData()
  },
  methods: {
    setTable() {
      // top 明细单列表
      this.tableList = {
        selectIndex: true,
        tableInfomation: [],
        allcol: [],
        showcol: this.showCol,
        tableColumn: this.setColumnVisible(this.showCol, this.tableColumn)
      }
      this.setTableList(this.tableList)

      // bottom 产品信息/库存信息/制造信息列表
      this.tableBottomColumn = this.productColumn
      this.showBottomCol = this.showProductCol
      this.setBottomList()
    },
    // bom 列表
    setBottomList() {
      this.productTableList = {
        selectIndex: true,
        tableInfomation: [],
        allcol: [],
        showcol: this.showBottomCol,
        tableColumn: this.setColumnVisible(this.showBottomCol, this.tableBottomColumn)
      }
      this.setTableList(this.productTableList)
    },
    setTableList(tableList) {
      tableList.allcol = tableList.tableColumn.filter((ele) => !ele.default).map((ele) => ele.label)
      this.searchOptions = []
      for (let i = 0; i < tableList.tableColumn.length; i++) {
        const label = tableList.tableColumn[i].label
        const value = tableList.tableColumn[i].prop
        this.searchOptions.push({ value: value, label: label })
      }
    },
    setColumnVisible(showCol, tableColumn) {
      return tableColumn.map((ele) => {
        return {
          ...ele,
          isShowColumn: showCol.includes(ele.label)
        }
      })
    },
    // top 明细单
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setColumnVisible(val, this.tableColumn)
    },
    // bottom 产品信息
    selBottomTableCol(val) {
      this.showcol = val
      this.productTableList.tableColumn = this.setColumnVisible(val, this.tableBottomColumn)
    },
    // 请求数据
    async getData() {
      this.loading = true
      let params = {}
      console.log(this.addConfig)
      if (this.addConfig.keywordType === "客户名称") {
        params = {
          clientId: this.addConfig.client_id,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else if (this.addConfig.keywordType === "销售机会") {
        params = {
          saleChanceId: this.addConfig.sale_chance_id,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else if (this.addConfig.keywordType === "销售子单") {
        params = {
          number: this.addConfig.subbill_name,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      } else {
        params = {
          keyword: this.keyword,
          keywordType: this.keywordType,
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize
        }
      }
      await getSalesDetailsList(params)
        .then((res) => {
          console.log(res)
          if (res.code === 200) {
            if (res.data.list && res.data.list.length > 0) {
              const list = res.data.list.map((item) => {
                return {
                  ...item,
                  client_name: item.client.name,
                  member_name: item.Member.username,
                  source: "CRM同步",
                  status: 2
                }
              })
              this.tableList.tableInfomation = list || []
              this.pagerOptions.totalCount = res.data.count
              if (res.data.count > 0) {
                this.selectRow = this.tableList.tableInfomation.length > 0 ? this.tableList.tableInfomation[0] : {}
                // let row = this.tableList.tableInfomation[0];
                // this.getPointinspectionRecord(row.id);
              }
            } else {
              this.tableList.tableInfomation = []
            }
          } else {
            this.tableList.tableInfomation = []
          }
          this.loading = false
        })
        .catch((err) => {
          console.log(err)
          this.tableList.tableInfomation = []
          this.loading = false
        })
    },
    // 搜索
    onFilterSearch(searchText) {
      this.keyword = searchText ?? ""
      this.keywordType = "订单编号"
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      console.log(this.addConfig)
      this.editConfig.infomation = {
        ...this.addConfig,
        currency: "人民币",
        sale_chance_name: "",
        subbill_name: "",
        client_name: this.addConfig?.client_name ?? "",
        quotation_number: ""
      }
    },
    // 查看 编辑
    handleClick(row, title) {
      console.log(row, title)
      this.editConfig.visible = true
      this.editConfig.title = title
      this.editConfig.infomation = {
        ...row,
        currency: "人民币",
        sale_chance_name: row.saleChance.name,
        deliverType: row.deliverType === 0 ? "" : row.deliverType,
        quotation_number: row.quotation.number
      }
    },
    // 确认提交
    submitClick(row) {
      console.log(row, "确认提交")
    },
    // 关闭
    closeClick(row) {
      console.log(row, "关闭")
    },
    // 删除
    delClick(rowID) {
      console.log(rowID, "xxxxshanchu")
      // if (this.selValueList && this.selValueList.length > 0) {
      this.$confirm("是否确认删除?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          getDelSalesDetails({ ids: [rowID] }).then((response) => {
            if (response.code === 200) {
              this.$message.success("删除成功")
              this.getData()
            } else {
              this.$message.warning("删除失败")
            }
          })
        })
        .catch(() => {})
      // } else {
      //   this.$message.warning("请至少选择一条记录")
      // }
    },
    getSelectArray(val) {
      console.log(val)
      this.selValueList = []
      const list = val.map((item) => {
        return item.id
      })
      this.selValueList = list
    },
    // 客户名称详情
    selClientClick(row) {
      console.log(row)
      this.clientDeail.visible = true
      this.clientDeail.infomation = {
        ...row.client,
        member: row.Member,
        client_name: row.client.name,
        client_level: row.client.client_level.name,
        client_status: row.client.client_status.name
      }
    },
    // 联系人详情
    selCommonClick(row) {
      this.specificationDetail.infomation = { ...row }
      this.specificationDetail.visible = true
    },
    addCollectionPlanClick(row) {
      this.addCollectionConfig.visible = true
      this.addCollectionConfig.title = "新建"
      this.addCollectionConfig.sourceType = 1
      this.addCollectionConfig.infomation = { ...row }
    },
    //获取当前选中资源的id
    getTab(tab) {
      this.TabsIndex = tab
      if (this.TabsIndex == 0) {
        this.isClickProduct = true
        this.isClickInventory = false
        this.isClickMake = false
        // 产品信息列表
        this.tableBottomColumn = this.productColumn
        this.showBottomCol = this.showProductCol
        this.setBottomList()
      } else if (this.TabsIndex == 1) {
        this.isClickProduct = false
        this.isClickInventory = true
        this.isClickMake = false
        // 库存信息列表
        this.tableBottomColumn = this.inventoryColumn
        this.showBottomCol = this.showInventoryCol
        this.setBottomList()
      } else if (this.TabsIndex == 2) {
        this.isClickProduct = false
        this.isClickInventory = false
        this.isClickMake = true
        // 制造信息列表
        this.tableBottomColumn = this.makeColumn
        this.showBottomCol = this.showMakeCol
        this.setBottomList()
      }
    },
    // 状态
    getStatus(val) {
      return val === 1 ? "待确认" : val === 2 ? "待出库" : val === 3 ? "出库完成" : val === 4 ? "已关闭" : "--"
    },
    // top 行点击
    tableRowClick(row, column, event) {
      console.log(row, column, event)
      this.selectRow = row
      // this.getPointinspectionRecord(row.id);
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
::v-deep {
  .el-table .el-table__cell {
    padding: 0;
  }
  .el-table__footer-wrapper tbody td.el-table__cell {
    height: 48px;
  }
}

.sales-details {
  height: 100%;
  overflow: hidden;
  .filter {
    height: 80px;
    display: flex;
    align-items: center;
    padding: 12px 20px 0 20px;
    &-card {
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      padding: 10px 20px;
      flex: 1;
      border-radius: 12px;
      background-color: #fff;
    }
  }
  .body {
    box-sizing: border-box;
    padding: 10px 20px;
    border-radius: 12px;
    height: calc(100% - 70px);
    .content-top {
      background-color: #fff;
      border-radius: 12px;
      min-height: 70px;
      height: 48%;
      position: relative;
      .list-view {
        height: calc(100% - 60px);
      }
    }
    .content-bottom {
      .bottom-tabs {
        height: 40px;
        line-height: 40px;
        background: #e6ecf2;
        display: flex;
        .tab-pane {
          width: 100px;
          margin-right: 20px;
          font-size: 14px !important;
          text-align: center;
          background: #2a78fb;
          border-top-left-radius: 20px;
          border-top-right-radius: 20px;
        }
      }
      .lable-view {
        background: #e6ecf2;
        height: 40px;
        line-height: 40px;
        .name {
          border-left: 4px solid #2a78fb;
          padding-left: 10px;
        }
      }
      background-color: #fff;
      border-radius: 12px;
      min-height: 70px;
      height: calc(52% - 60px);
      margin-top: 10px;
      // padding: 10px 20px;
      .list-view {
        height: calc(100% - 10px);
      }
    }
    .btn-pager {
      display: flex;
      margin-top: 10px;
      .page {
        margin-left: auto;
      }
    }
  }
}

.bgcGrey {
  background: #e6ecf2;
}
.bgcWhite {
  background: #fff !important;
}
</style>
